Compute the degrees of freedom for the variance estimator
Arguments
- n
number of observations
- coef
moving average (
moving_average()) used to filter the series.- exact_df
if
TRUEcompute the exact degrees of freedom for the t-distribution (whengaussian_distribution = FALSE), otherwise uses an approximation.
Examples
df_var(n = 100, coef = lp_filter(6)@sfilter)
#> [1] 63.68573